==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GeographicSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var GeographicSymbolSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicSymbolSeriesBaseDescriptionMetadata, _super);
    function GeographicSymbolSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicSymbolSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicSymbolSeriesBaseDescriptionMetadata.a == null) {
            GeographicSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicSymbolSeriesBaseDescriptionMetadata.c(GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
        if (a.g(GeographicSymbolSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(GeographicSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicSymbolSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
    };
    GeographicSymbolSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicSymbolSeriesBaseDescriptionMetadata.b(a);
        a.t("GeographicSymbolSeriesBase", GeographicSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicSymbolSeriesBaseDescriptionMetadata, 'GeographicSymbolSeriesBaseDescriptionMetadata');
    GeographicSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicSymbolSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicSymbolSeriesBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
var GeographicSymbolSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicSymbolSeriesBaseDescriptionMetadata, _super);
    function GeographicSymbolSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicSymbolSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicSymbolSeriesBaseDescriptionMetadata.a == null) {
            GeographicSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicSymbolSeriesBaseDescriptionMetadata.c(GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
        if (a.j(GeographicSymbolSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicSymbolSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
    };
    GeographicSymbolSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicSymbolSeriesBaseDescriptionMetadata.b(a);
        a.z("GeographicSymbolSeriesBase", GeographicSymbolSeriesBaseDescriptionMetadata.a);
    };
    GeographicSymbolSeriesBaseDescriptionMetadata.$t = markType(GeographicSymbolSeriesBaseDescriptionMetadata, 'GeographicSymbolSeriesBaseDescriptionMetadata');
    GeographicSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicSymbolSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicSymbolSeriesBaseDescriptionMetadata };
